@@ -323,17 +323,17 @@ class BaseBot:
 
             if cmd and ((msg.is_whisper and cmd.context & CommandContext.WHISPER)
                         or (msg.is_privmsg and cmd.context & CommandContext.CHANNEL)):
-                print(msg)
+                msg.safe_print()
                 coro = self._run_command(msg, cmd)
 
             elif msg.type is MessageType.WHISPER:
-                print(msg)
+                msg.safe_print()
                 coro = self.on_whisper_received(msg)
                 mod_coro = trigger_mod_event(Event.on_whisper_received, msg)
                 event_coro = trigger_event(Event.on_whisper_received, msg)
 
             elif msg.type is MessageType.PRIVMSG:
-                print(msg)
+                msg.safe_print()
                 coro = self.on_privmsg_received(msg)
                 mod_coro = trigger_mod_event(Event.on_privmsg_received, msg, channel=msg.channel_name)
                 event_coro = trigger_event(Event.on_privmsg_received, msg)
@@ -384,12 +384,12 @@ class BaseBot:
                 mod_coro = trigger_mod_event(Event.on_bits_donated, msg, msg.tags.bits, channel=msg.channel_name)
                 event_coro = trigger_event(Event.on_bits_donated, msg.channel, msg)
 
-            elif msg.type == MessageType.BOT_PERMANENTLY_BANNED:
+            elif msg.type is MessageType.BOT_PERMANENTLY_BANNED:
                 coro = self.on_bot_banned_from_channel(msg, msg.channel)
                 mod_coro = trigger_mod_event(Event.on_bot_banned_from_channel, msg, msg.channel, channel=msg.channel_name)
                 event_coro = trigger_event(Event.on_bot_banned_from_channel, msg, msg.channel)
 
-            elif msg.type == MessageType.BOT_TIMED_OUT:
+            elif msg.type is MessageType.BOT_TIMED_OUT:
                 coro = self.on_bot_timed_out_from_channel(msg, msg.channel, msg.timeout_seconds)
                 mod_coro = trigger_mod_event(Event.on_bot_timed_out_from_channel, msg, msg.channel, msg.timeout_seconds, channel=msg.channel_name)
                 event_coro = trigger_event(Event.on_bot_timed_out_from_channel, msg, msg.channel, msg.timeout_seconds)
