@@ -1,3 +1,5 @@
+import traceback
+from datetime import datetime
 from itertools import islice
 from typing import List, Tuple, TYPE_CHECKING, Optional, Callable, Awaitable, FrozenSet
 
@@ -304,6 +306,15 @@ class Message:
 
         return self.raw_msg
 
+    def safe_print(self):
+        try:
+            print(self)
+        except Exception as e:
+            err = traceback.format_exc()
+            print(err)
+            with open('printing_errors.log', 'a') as f:
+                f.write(f'\n\n{datetime.now()}:\n{err}')
+
     def __getitem__(self, item):
         """
         if item is a slice, returns a space joined parts of that slice
